- 2.0.3 (23-05-2017)
- add find() and find_one()

- 2.0.2 (24-03-2017)
- support unset

- 2.0.1 (6-02-2017)
- Hack support ObjectId
- Fix minor bugs

- 2.0.0 (29-12-2016)
- (!!) Changed validation system to cerberus (http://python-cerberus.org) check README.md

- 1.0.8 (12-12-2016)
- Support insert id by create method

- 1.0.7 (03-12-2016)
- Avoid recursive validation (inspect_recursive=False)

- 1.0.6 (10-11-2016)
- Fix .model in find method

- 1.0.5 (05-10-2016)
- Fix remove item

- 1.0.4 (29-9-2016)
- support custom_id

- 1.0.3 (28-9-2016)
- automatic creation

# 1.0.2 (18-7-2016)
- add method insert()

# 1.0.1 (12-7-2016)
- remove prints

# 1.0.0 (12-7-2016)
- auto_get = True
- disable automatic discover cache
- if you use auto_get = False must make a .get() to get the data in the class
- Add support Python 2

# 0.1.0 (11-7-2016)
- Add collect property

# 0.0.5 (11-7-2016)
- fix require=False and value None

# 0.0.4 (6-6-2016)
- Update readme

# 0.0.3 (6-6-2016)
- Update readme
- Fix minor bugs

# 0.0.2 (3-6-2016)
- Fix pip install

# 0.0.1 (3-6-2016)
- Initial version
